
Prometheus
==========

PSF photometry package.

Authors
-------

- **David Nidever** (Montana State University)

Installation
------------

To install the latest version::

    pip install git+https://github.com/dnidever/prometheus

Attribution
-----------
    
.. image:: https://zenodo.org/badge/363221788.svg
   :target: https://zenodo.org/badge/latestdoi/363221788
    
Documentation
-------------

.. image:: https://readthedocs.org/projects/theprometheus/badge/?version=latest
        :target: http://theprometheus.readthedocs.io/

See `the documentation <http://theprometheus.readthedocs.io>`_ for information on how
to install and use Prometheus.

License
-------

.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
        :target: https://github.com/dnidever/prometheus/blob/main/LICENSE
